import { Inter } from 'next/font/google'
import './globals.css'

import { ThemeProvider } from '@/components/ui/theme-provider'
import { Toaster } from '@/components/ui/toaster'
import { siteConfig } from "@/lib/config/site"
import Providers from '@/lib/react-query/provider'

const inter = Inter({ subsets: ['latin'] })

export const metadata = {
    title: {
        default: siteConfig.name,
        template: `%s | ${siteConfig.name}`,
    },
    description: siteConfig.description,
    keywords: [
        "Next.js",
        "React",
        "Tailwind CSS",
        "Server Components",
        "Radix UI",
        "TypeScript",
        "ESLint",
        "Prisma ORM",
        "PostgreSQL",
        "Vercel",
        "Jest",
        "IGDB",
    ],
    authors: [
        {
            name: "Yusuf Akgül",
        },
        {
            name: "Caner Ilaslan",
        },
        {
            name: "David Jakszta",
        },
        {
            name: "Omar Kasbah",
        },
        {
            name: "Serdar Dorak",
        },
        {
            name: "Valeria Luft",
        },
    ],
    creator: "The Golden Order Studio",
    themeColor: [
        { media: "(prefers-color-scheme: light)", color: "white" },
        { media: "(prefers-color-scheme: dark)", color: "black" },
    ],
    openGraph: {
        type: "website",
        locale: "en_US",
        url: siteConfig.url,
        title: siteConfig.name,
        description: siteConfig.description,
        siteName: siteConfig.name,
    },
    twitter: {
        card: "summary_large_image",
        title: siteConfig.name,
        description: siteConfig.description,
        images: [`${siteConfig.url}/og.jpg`],
        creator: "@shadcn",
    },
    icons: {
        icon: "/favicon.ico",
        shortcut: "/favicon-16x16.png",
        apple: "/apple-touch-icon.png",
    },
    manifest: `${siteConfig.url}/site.webmanifest`,
}

export default function RootLayout({
    children,
}: {
    children: React.ReactNode
}) {
    return (
        <html lang="en" suppressHydrationWarning>
            <head />
            <body className={inter.className}>
                <ThemeProvider attribute="class" defaultTheme="system" enableSystem>
                    <Providers>
                        {children}
                        <Toaster />
                    </Providers>
                </ThemeProvider>
            </body>
        </html>
    )
}